<?php

namespace Drupal\views_taxonomy_radios_filter\Plugin\views\filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\taxonomy\Plugin\views\filter\TaxonomyIndexTid as TaxonomyIndexTidFilter;

/**
 * Display a radios/checkboxes filter for Taxonomy term id.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("taxonomy_index_tid_radios")
 */
class TaxonomyIndexTid extends TaxonomyIndexTidFilter {

  /**
   * {@inheritDoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $views_ui_key = \Drupal::config('views.settings')->get('ui.exposed_filter_any_label') ?? 'new_any';
    $views_ui_labels = ['old_any' => '&lt;Any&gt;', 'new_any' => '- Any -'];
    $options['all_label'] = ['default' => $views_ui_labels[$views_ui_key]];

    return $options;
  }

  /**
   * {@inheritDoc}
   */
  public function buildExtraOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildExtraOptionsForm($form, $form_state);

    $form['type']['#options']['radios'] = $this->t('Radios/Checkboxes');

    $form['all_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t("'All' value's label"),
      '#default_value' => $this->options['all_label'],
      '#size' => 25,
      '#states' => [
        'visible' => [
          ':input[name="options[type]"]' => ['value' => 'radios'],
        ],
        'required' => [
          ':input[name="options[type]"]' => ['value' => 'radios'],
        ],
      ],
    ];
  }

  /**
   * {@inheritDoc}
   */
  protected function valueForm(&$form, FormStateInterface $form_state) {
    parent::valueForm($form, $form_state);
    
    if (!$form_state->get('exposed')) {
      return;
    }
    
    $multiple = $this->options['expose']['multiple'] ?? FALSE;
    $identifier = $this->options['expose']['identifier'] ?? FALSE;

    if ($this->options['type'] == 'radios') {
      $form['value']['#type'] = $multiple ? 'checkboxes' : 'radios';
      unset($form['value']['#multiple'], $form['value']['#size']);

      // Custom "All" label for better UI.
      $form['value']['#all_label'] = $this->options['all_label'];

      // Reapply custom form element to form.
      $form[$identifier] = $form['value'];
    }
  }

  /**
   * {@inheritDoc}
   */
  protected function exposedTranslate(&$form, $type) {
    $original_filter_type = $form['#type'];

    // By default, views transform radios and checkboxes to select element.
    parent::exposedTranslate($form, $type);

    if (in_array($original_filter_type, ['radios', 'checkboxes'])) {      
      $multiple = $this->options['expose']['multiple'] ?? FALSE;
      $form['#type'] = $multiple ? 'checkboxes' : 'radios';
    }
  }
  
}
